==> shoppingCart-1.3.0.tar.gz: shoppingCart-1.3.0/shoppingCart/release.py <==
#!/usr/bin/python
# -*- encoding: utf-8 -*-
################################################################################
#
#    Copyright (C) 2010 Dharmesh Patel <mr.dlpatel@gmail.com>.
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################

name            = 'shoppingCart'
version         = '1.3.0'
major_version   = '1'
description     = 'shoppingCart is a open source cart developed using Python language to manage cart in Ecommerce applications.'
long_description= """
Majour Feature(s):

1. Product options support.
2. Multi discount support.
3. Multi tax support(specific to product as well as general taxes).
4. Multi currency support.
5. Tax Exclude and Include total.
6. Shipping method and charge.
"""
classifiers     = [
                        "Development Status :: 5 - Production/Stable",
                        "License :: OSI Approved :: BSD License",
                        "Programming Language :: Python"
                     ]
url             = 'http://bitbucket.org/dharmeshpatel/shoppingcart'
author          = 'Dharmesh Patel'
author_email    = 'mr[dot]dlpatel[at]gmail[dot]com'
copyright       = 'Copyright (c) 2010 Dharmesh Patel'
license         = 'BSD'

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> shoppingCart-1.4.2.tar.gz: shoppingCart-1.4.2/shoppingCart/release.py <==
#!/usr/bin/python
# -*- encoding: utf-8 -*-
################################################################################
#
#    Copyright (C) 2010 - 2015 Dharmesh Patel <mr.dlpatel@gmail.com>.
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################

name            = 'shoppingCart'
version         = '1.4.2'
major_version   = '1'
description     = 'shoppingCart is a open source cart developed using Python language to manage cart in Ecommerce applications.'
long_description= """
Majour Feature(s):

1. Product options support.
2. Multi discount support.
3. Multi tax support(specific to product as well as general taxes).
4. Multi currency support.
5. Tax Exclude and Include total.
6. Shipping method and charge.
"""
classifiers     = [
                        "Development Status :: 5 - Production/Stable",
                        "License :: OSI Approved :: BSD License",
                        "Programming Language :: Python"
                     ]
url             = 'https://github.com/dharmeshpatel/shoppingcart'
author          = 'Dharmesh Patel'
author_email    = 'mr[dot]dlpatel[at]gmail[dot]com'
copyright       = 'Copyright (c) 2010 - 2015 Dharmesh Patel'
license         = 'BSD'

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
